From 966e6fddf3e77e21fac27a9ecf79976066443bdf Mon Sep 17 00:00:00 2001
From: Ryan Kurtz
Date: Thu, 18 Apr 2024 08:28:52 -0400
Subject: [PATCH] GP-4122: Switching to JDK 21
---
Ghidra/application.properties | 6 +++---
GhidraDocs/InstallationGuide.html | 10 +++++-----
README.md | 8 ++++----
build.gradle | 3 ++-
4 files changed, 14 insertions(+), 13 deletions(-)
diff --git a/Ghidra/application.properties b/Ghidra/application.properties
index 4f8b5f2ee4..49cdcca99b 100644
--- a/Ghidra/application.properties
+++ b/Ghidra/application.properties
@@ -2,8 +2,8 @@ application.name=Ghidra
application.version=11.2
application.release.name=DEV
application.layout.version=2
-application.gradle.min=7.3
+application.gradle.min=8.5
application.gradle.max=
-application.java.min=17
+application.java.min=21
application.java.max=
-application.java.compiler=17
+application.java.compiler=21
diff --git a/GhidraDocs/InstallationGuide.html b/GhidraDocs/InstallationGuide.html
index 22bcd35509..eb44b8b3f1 100644
--- a/GhidraDocs/InstallationGuide.html
+++ b/GhidraDocs/InstallationGuide.html
@@ -19,7 +19,7 @@
Ghidra Installation Guide
-The installation information provided is effective as of Ghidra 11.1 and is subject to change with
+The installation information provided is effective as of Ghidra 11.2 and is subject to change with
future releases.
@@ -84,16 +84,16 @@ Ghidra team if you have a specific need.
Software
- - Java 17 64-bit Runtime and Development Kit (JDK) (see Java Notes)
+ - Java 21 64-bit Runtime and Development Kit (JDK) (see Java Notes)
- - Free long term support (LTS) versions of JDK 17 are provided by:
+ - Free long term support (LTS) versions of JDK 21 are provided by:
@@ -335,7 +335,7 @@ In order to build native binaries for your platform, you will need the following
system:
- A supported version of a Java Development Kit
- - Gradle 7.3+
+ - Gradle 8.5+
- Software C/C++ build tools and library packages
- macOS: Xcode or the abbreviated Command Line Tools for Xcode will supply the
diff --git a/README.md b/README.md
index e45f876324..fc66d12629 100644
--- a/README.md
+++ b/README.md
@@ -29,7 +29,7 @@ of how you might be impacted.
## Install
To install an official pre-built multi-platform Ghidra release:
-* Install [JDK 17 64-bit][jdk17]
+* Install [JDK 21 64-bit][jdk]
* Download a Ghidra [release file][releases]
- **NOTE:** The official multi-platform release file is named
`ghidra___.zip` which can be found under the "Assets" drop-down.
@@ -46,8 +46,8 @@ directory.
To create the latest development build for your platform from this source repository:
##### Install build tools:
-* [JDK 17 64-bit][jdk17]
-* [Gradle 7.3+][gradle]
+* [JDK 21 64-bit][jdk]
+* [Gradle 8.5+][gradle]
* [Python3][python3] (version 3.7 to 3.12) with bundled pip
* make, gcc, and g++ (Linux/macOS-only)
* [Microsoft Visual Studio][vs] 2017+ or [Microsoft C++ Build Tools][vcbuildtools] with the
@@ -127,7 +127,7 @@ source project.
[known-issues]: DevGuide.md#known-issues
[career]: https://www.intelligencecareers.gov/nsa
[releases]: https://github.com/NationalSecurityAgency/ghidra/releases
-[jdk17]: https://adoptium.net/temurin/releases
+[jdk]: https://adoptium.net/temurin/releases
[gradle]: https://gradle.org/releases/
[python3]: https://www.python.org/downloads/
[vs]: https://visualstudio.microsoft.com/vs/community/
diff --git a/build.gradle b/build.gradle
index 75a2acf404..6af4593b1c 100644
--- a/build.gradle
+++ b/build.gradle
@@ -21,9 +21,10 @@ apply from: "gradle/support/loadApplicationProperties.gradle"
/***************************************************************************************
* Print current Gradle version and make sure the correct version of gradle is being used
***************************************************************************************/
import org.gradle.util.GradleVersion;
+println "Java: " + JavaVersion.current()
println "Gradle: " + GradleVersion.current().version
checkGradleVersion()
@@ -21,9 +21,10 @@ apply from: "gradle/support/loadApplicationProperties.gradle"
/***************************************************************************************
-* Print current Gradle version and make sure the correct version of gradle is being used
+* Print current Java and Gradle version and make sure the correct version of gradle is being used
***************************************************************************************/
import org.gradle.util.GradleVersion;